from .File import create
from .File import edit
from .File import access
from .localweather import location
from .localweather import weather
from .search import google
from .search import youtubeplay
from .search import youtubesearch
from .searchwiki import text
from .searchwiki import voice
from .sendmail import send
from .social import gmail
from .social import facebookemail
from .social import facebooknum
from .speech import speak
from .speech import takecommand
from .speech import intro
from .system import shutdown
from .system import restart
from .system import openfile
from .websites import Open
from .whatisthetime import date
from .whatisthetime import time


